foxtrot
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Documentation can be found at https://licenseplated.github.io/foxtrot

## Install

``` sh
pip install foxtrot-beta
```
